==> a2ps_4.10.2.orig.tar.gz: a2ps-4.10.2/lib/stream.h <==
/*
 * stream.h
 *
 * 
 *
 * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
 * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
 *
 */

/*
 * This file is part of a2ps.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * $Id: stream.h,v 1.4 1998/03/03 15:51:22 demaille Exp $
 */
#ifndef _STREAM_H_
#define _STREAM_H_

struct stream {
  boolean is_file;	/* Is it a file (no : pipe)		*/
  FILE * fp;
};

/* Open for reading */
struct stream * stream_ropen PARAMS ((const char * command, 
				      boolean is_file));
/* Open for writing */
struct stream * stream_wopen PARAMS ((const char * command,
				      boolean is_file));


/*
 * Uses the perl convention to know whether file or pipe
 * I.e., command starts by '>', or '|'
 */
struct stream * stream_perl_open PARAMS ((char const * perl_command));

/* Closes and frees.  */
void stream_close PARAMS ((struct stream * stream));

#endif

==> a2ps-4.10.4.tar.gz: a2ps-4.10.4/lib/stream.h <==
/*
 * stream.h
 *
 * 
 *
 * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
 * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
 *
 */

/*
 * This file is part of a2ps.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * $Id: stream.h,v 1.4 1998/03/03 15:51:22 demaille Exp $
 */
#ifndef _STREAM_H_
#define _STREAM_H_
#include "xbackupfile.h"

struct stream {
  boolean is_file;	/* Is it a file (no : pipe)		*/
  FILE * fp;
};

/* Open for reading */
struct stream * stream_ropen PARAMS ((const char * command, 
				      boolean is_file));
/* Open for writing */
struct stream * stream_wopen PARAMS ((const char * command,
				      boolean is_file));
/* Open for writing, using backup services */
struct stream * stream_wopen_backup PARAMS ((const char * command, 
					     boolean is_file, 
					     enum backup_type backup_type));

/*
 * Uses the perl convention to know whether file or pipe
 * I.e., command starts by '>', or '|'
 */
struct stream * stream_perl_open PARAMS ((char const * perl_command));

/* Closes and frees.  */
void stream_close PARAMS ((struct stream * stream));

#endif
